# -*- coding: utf-8 -*-
#
# Copyright (C) 2021 CERN.
#
# Invenio-Drafts-Resources is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""System fields."""

from .parent import ParentField
from .versions import VersionsField

__all__ = (
    "ParentField",
    "VersionsField",
)
